/*
*  Name:      test-sqlstate_handler.cc
*  Author:    Rafael Jesus Alcantara Perez
*  Summary:   Test for class TSqlstateHandler
*  Date:      $Date: 1999/09/20 10:08:31 $
*  Revision:  $Revision: 1.2 $
*
*  Copyright (C) 1999  Rafael Jesus Alcantara Perez <ralcan@vnet.es>
*
*  This program is free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  This program is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  You should have received a copy of the GNU General Public License
*  along with this program; if not, write to the Free Software
*  Foundation, Inc., 59 Temple Place, Suite 330, Boston,
*  MA 02111-1307, USA.
*/

#include <mpcl/string.hh>
#include <mpcl/test.h>
#include "defs-uesqlc.hh"


//
//  U S E D   N A M E S P A C E S
//

using namespace mpcl;
using namespace uesql;


///  Main.
int main (void)
{

  TEST_INIT ("tests for class 'TSqlstateHandler'");
  TEST_START_WATCH;

  TSqlstateHandler   tSqlstateHandler;

  //
  //  Tests for class messages.
  //
  TEST_STRINGS (tSqlstateHandler.getClass ("3C000"), "ambiguous cursor name");
  TEST_STRINGS (tSqlstateHandler.getClass ("21000"), "cardinality violation");
  TEST_STRINGS (tSqlstateHandler.getClass ("08000"), "connection exception");
  TEST_STRINGS (tSqlstateHandler.getClass ("08003"), "connection exception");
  TEST_STRINGS (tSqlstateHandler.getClass ("08006"), "connection exception");
  TEST_STRINGS (tSqlstateHandler.getClass ("08002"), "connection exception");
  TEST_STRINGS (tSqlstateHandler.getClass ("08001"), "connection exception");
  TEST_STRINGS (tSqlstateHandler.getClass ("08004"), "connection exception");
  TEST_STRINGS (tSqlstateHandler.getClass ("08007"), "connection exception");
  TEST_STRINGS (tSqlstateHandler.getClass ("22000"), "data exception");
  TEST_STRINGS (tSqlstateHandler.getClass ("22021"), "data exception");
  TEST_STRINGS (tSqlstateHandler.getClass ("22008"), "data exception");
  TEST_STRINGS (tSqlstateHandler.getClass ("22012"), "data exception");
  TEST_STRINGS (tSqlstateHandler.getClass ("22005"), "data exception");
  TEST_STRINGS (tSqlstateHandler.getClass ("22022"), "data exception");
  TEST_STRINGS (tSqlstateHandler.getClass ("22015"), "data exception");
  TEST_STRINGS (tSqlstateHandler.getClass ("22018"), "data exception");
  TEST_STRINGS (tSqlstateHandler.getClass ("22007"), "data exception");
  TEST_STRINGS (tSqlstateHandler.getClass ("22019"), "data exception");
  TEST_STRINGS (tSqlstateHandler.getClass ("22025"), "data exception");
  TEST_STRINGS (tSqlstateHandler.getClass ("22023"), "data exception");
  TEST_STRINGS (tSqlstateHandler.getClass ("22009"), "data exception");
  TEST_STRINGS (tSqlstateHandler.getClass ("22002"), "data exception");
  TEST_STRINGS (tSqlstateHandler.getClass ("22003"), "data exception");
  TEST_STRINGS (tSqlstateHandler.getClass ("22026"), "data exception");
  TEST_STRINGS (tSqlstateHandler.getClass ("22001"), "data exception");
  TEST_STRINGS (tSqlstateHandler.getClass ("22011"), "data exception");
  TEST_STRINGS (tSqlstateHandler.getClass ("22027"), "data exception");
  TEST_STRINGS (tSqlstateHandler.getClass ("22024"), "data exception");
  TEST_STRINGS (tSqlstateHandler.getClass ("2B000"), "dependent privilege descriptors still exist");
  TEST_STRINGS (tSqlstateHandler.getClass ("07000"), "dynamic SQL error");
  TEST_STRINGS (tSqlstateHandler.getClass ("07003"), "dynamic SQL error");
  TEST_STRINGS (tSqlstateHandler.getClass ("07008"), "dynamic SQL error");
  TEST_STRINGS (tSqlstateHandler.getClass ("07009"), "dynamic SQL error");
  TEST_STRINGS (tSqlstateHandler.getClass ("07005"), "dynamic SQL error");
  TEST_STRINGS (tSqlstateHandler.getClass ("07006"), "dynamic SQL error");
  TEST_STRINGS (tSqlstateHandler.getClass ("07001"), "dynamic SQL error");
  TEST_STRINGS (tSqlstateHandler.getClass ("07002"), "dynamic SQL error");
  TEST_STRINGS (tSqlstateHandler.getClass ("07004"), "dynamic SQL error");
  TEST_STRINGS (tSqlstateHandler.getClass ("07007"), "dynamic SQL error");
  TEST_STRINGS (tSqlstateHandler.getClass ("0A000"), "feature not supported");
  TEST_STRINGS (tSqlstateHandler.getClass ("0A001"), "feature not supported");
  TEST_STRINGS (tSqlstateHandler.getClass ("23000"), "integrity constraint violation");
  TEST_STRINGS (tSqlstateHandler.getClass ("28000"), "invalid authorization specification");
  TEST_STRINGS (tSqlstateHandler.getClass ("3D000"), "invalid catalog name");
  TEST_STRINGS (tSqlstateHandler.getClass ("2C000"), "invalid character set name");
  TEST_STRINGS (tSqlstateHandler.getClass ("35000"), "invalid condition number");
  TEST_STRINGS (tSqlstateHandler.getClass ("2E000"), "invalid connection name");
  TEST_STRINGS (tSqlstateHandler.getClass ("34000"), "invalid cursor name");
  TEST_STRINGS (tSqlstateHandler.getClass ("24000"), "invalid cursor state");
  TEST_STRINGS (tSqlstateHandler.getClass ("3F000"), "invalid schema name");
  TEST_STRINGS (tSqlstateHandler.getClass ("33000"), "invalid SQL descriptor name");
  TEST_STRINGS (tSqlstateHandler.getClass ("26000"), "invalid SQL statement name");
  TEST_STRINGS (tSqlstateHandler.getClass ("25000"), "invalid transaction state");
  TEST_STRINGS (tSqlstateHandler.getClass ("2D000"), "invalid transaction termination");
  TEST_STRINGS (tSqlstateHandler.getClass ("02000"), "no data");
  TEST_STRINGS (tSqlstateHandler.getClass ("HZ000"), "remote database access");
  TEST_STRINGS (tSqlstateHandler.getClass ("00000"), "successful completion");
  TEST_STRINGS (tSqlstateHandler.getClass ("42000"), "syntax error or access rule violation");
  TEST_STRINGS (tSqlstateHandler.getClass ("2A000"), "syntax error or access rule violation in direct statement");
  TEST_STRINGS (tSqlstateHandler.getClass ("37000"), "syntax error or access rule violation in dynamic statement");
  TEST_STRINGS (tSqlstateHandler.getClass ("40000"), "transaction rollback");
  TEST_STRINGS (tSqlstateHandler.getClass ("40002"), "transaction rollback");
  TEST_STRINGS (tSqlstateHandler.getClass ("40001"), "transaction rollback");
  TEST_STRINGS (tSqlstateHandler.getClass ("40003"), "transaction rollback");
  TEST_STRINGS (tSqlstateHandler.getClass ("27000"), "triggered data change violation");
  TEST_STRINGS (tSqlstateHandler.getClass ("01000"), "warning");
  TEST_STRINGS (tSqlstateHandler.getClass ("01001"), "warning");
  TEST_STRINGS (tSqlstateHandler.getClass ("01002"), "warning");
  TEST_STRINGS (tSqlstateHandler.getClass ("01008"), "warning");
  TEST_STRINGS (tSqlstateHandler.getClass ("01005"), "warning");
  TEST_STRINGS (tSqlstateHandler.getClass ("01003"), "warning");
  TEST_STRINGS (tSqlstateHandler.getClass ("01007"), "warning");
  TEST_STRINGS (tSqlstateHandler.getClass ("01006"), "warning");
  TEST_STRINGS (tSqlstateHandler.getClass ("0100A"), "warning");
  TEST_STRINGS (tSqlstateHandler.getClass ("01009"), "warning");
  TEST_STRINGS (tSqlstateHandler.getClass ("01004"), "warning");
  TEST_STRINGS (tSqlstateHandler.getClass ("44000"), "with check option violation");

  //
  //  Tests for subclass messages.
  //
  TEST_STRINGS (tSqlstateHandler.getSubclass ("3C000"), "(no subclass)");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("21000"), "(no subclass)");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("08000"), "(no subclass)");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("08003"), "connection does not exist");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("08006"), "connection failure");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("08002"), "connection name in use");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("08001"), "SQL-client unable to establish SQL-connection");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("08004"), "SQL-server rejected establishment of SQL-connection");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("08007"), "transaction resolution unknown");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("22000"), "(no subclass)");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("22021"), "character not in repertoire");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("22008"), "datetime field overflow");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("22012"), "division by zero");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("22005"), "error in assignment");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("22022"), "indicator overflow");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("22015"), "interval field overflow");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("22018"), "invalid character value for cast");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("22007"), "invalid datetime format");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("22019"), "invalid escape character");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("22025"), "invalid escape sequence");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("22023"), "invalid parameter value");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("22009"), "invalid time zone displacement value");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("22002"), "null value, no indicator parameter");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("22003"), "numeric value out of range");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("22026"), "string data, length mismatch");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("22001"), "string data, right truncation");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("22011"), "substring error");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("22027"), "trim error");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("22024"), "unterminated C string");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("2B000"), "(no subclass)");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("07000"), "(no subclass)");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("07003"), "cursor specification cannot be executed");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("07008"), "invalid descriptor count");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("07009"), "invalid descriptor index");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("07005"), "prepared statement not a cursor specification");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("07006"), "restricted data type attribute violation");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("07001"), "using clause does not match dynamic parameter specifications");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("07002"), "using clause does not match target specifications");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("07004"), "using clause required for dynamic parameters");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("07007"), "using clause required for result fields");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("0A000"), "(no subclass)");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("0A001"), "multiple environment transactions");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("23000"), "(no subclass)");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("28000"), "(no subclass)");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("3D000"), "(no subclass)");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("2C000"), "(no subclass)");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("35000"), "(no subclass)");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("2E000"), "(no subclass)");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("34000"), "(no subclass)");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("24000"), "(no subclass)");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("3F000"), "(no subclass)");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("33000"), "(no subclass)");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("26000"), "(no subclass)");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("25000"), "(no subclass)");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("2D000"), "(no subclass)");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("02000"), "(no subclass)");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("HZ000"), "(no subclass)");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("00000"), "(no subclass)");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("42000"), "(no subclass)");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("2A000"), "(no subclass)");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("37000"), "(no subclass)");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("40000"), "(no subclass)");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("40002"), "integrity constraint violation");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("40001"), "serialization failure");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("40003"), "statement completion unknown");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("27000"), "(no subclass)");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("01000"), "(no subclass)");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("01001"), "cursor operation conflict");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("01002"), "disconnect error");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("01008"), "implicit zero-bit padding");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("01005"), "insufficient item descriptor areas");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("01003"), "null value eliminated in set function");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("01007"), "privilege not granted");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("01006"), "privilege not revoked");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("0100A"), "query expression too long for information schema");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("01009"), "search condition too long for information schema");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("01004"), "string data, right truncation");
  TEST_STRINGS (tSqlstateHandler.getSubclass ("44000"), "(no subclass)");
  TEST_STOP_WATCH;

  TEST_DISPLAY_WATCH;
  TEST_MEMORY_STATUS;
  TEST_RETURN_CODE;

}  // main()
